==> elgg-1.10.1.zip: elgg-1.10.1/mod/reportedcontent/languages/fi.php <==
<?php
return array(

	'item:object:reported_content' => 'Ilmiannetut kohteet',
	'admin:administer_utilities:reportedcontent' => 'Asiaton sisältö',
	'reportedcontent' => 'Asiaton sisältö',
	'reportedcontent:this' => 'Ilmoita asiattomasta sisällöstä',
	'reportedcontent:this:tooltip' => 'Ilmoita sivun ylläpitäjälle asiattomasta sisällöstä',
	'reportedcontent:none' => 'Ei ilmoituksia',
	'reportedcontent:report' => 'Ilmoita ylläpitäjälle',
	'reportedcontent:deleted' => 'Ilmoitus poistettu',
	'reportedcontent:notdeleted' => 'Ilmoituksen poistaminen epäonnistui',
	'reportedcontent:delete' => 'Poista ilmoitus',
	'reportedcontent:areyousure' => 'Haluatko varmasti poistaa tämän kohteen?',
	'reportedcontent:archive' => 'Arkistoi ilmoitus',
	'reportedcontent:archived' => 'Ilmoitus arkistoitiin',
	'reportedcontent:visit' => 'Siirry ilmiannettuun kohteeseen',
	'reportedcontent:by' => 'Ilmoitus käyttäjältä',
	'reportedcontent:objecttitle' => 'Kohteen otsikko',
	'reportedcontent:objecturl' => 'Kohteen sijainti',
	'reportedcontent:reason' => 'Miksi sisältö on mielestäsi asiatonta',
	'reportedcontent:description' => 'Miksi ilmoitat tästä',
	'reportedcontent:address' => 'Kohteen sijainti',
	'reportedcontent:success' => 'Ilmoitus lähetettiin sivuston ylläpitäjälle',
	'reportedcontent:failing' => 'Ilmoituksen lähettäminen epäonnistui',
	'reportedcontent:report' => 'Ilmoita ylläpitäjälle',
	'reportedcontent:instructions' => 'Tämä ilmoitus lähetetään sivuston ylläpitäjälle tarkistettavaksi.',
	'reportedcontent:numbertodisplay' => 'Näytettävien kohteiden määrä',
	'reportedcontent:widget:description' => 'Näytä ilmiannettu kohde',
	'reportedcontent:user' => 'Ilmianna käyttäjä',

	'reportedcontent:failed' => 'Ilmoituksen tekeminen epäonnistui.',
	'reportedcontent:notarchived' => 'Ilmoituksen arkistoiminen epäonnistui',
);

==> elgg-3.0.5.zip: elgg-3.0.5/mod/reportedcontent/languages/fi.php <==
<?php
return array(

	'item:object:reported_content' => 'Ilmiannetut kohteet',
	'admin:administer_utilities:reportedcontent' => 'Asiaton sisältö',
	'reportedcontent' => 'Asiaton sisältö',
	'reportedcontent:this' => 'Ilmoita asiattomasta sisällöstä',
	'reportedcontent:this:tooltip' => 'Ilmoita sivun ylläpitäjälle asiattomasta sisällöstä',
	'reportedcontent:none' => 'Ei ilmoituksia',
	'reportedcontent:report' => 'Ilmoita ylläpitäjälle',
	'reportedcontent:deleted' => 'Ilmoitus poistettu',
	'reportedcontent:notdeleted' => 'Ilmoituksen poistaminen epäonnistui',
	'reportedcontent:delete' => 'Poista ilmoitus',
	'reportedcontent:archive' => 'Arkistoi ilmoitus',
	'reportedcontent:archived' => 'Ilmoitus arkistoitiin',
	'reportedcontent:by' => 'Ilmoitus käyttäjältä',
	'reportedcontent:objecttitle' => 'Kohteen otsikko',
	'reportedcontent:objecturl' => 'Kohteen sijainti',
	'reportedcontent:reason' => 'Miksi sisältö on mielestäsi asiatonta',
	'reportedcontent:description' => 'Miksi ilmoitat tästä',
	'reportedcontent:address' => 'Kohteen sijainti',
	'reportedcontent:success' => 'Ilmoitus lähetettiin sivuston ylläpitäjälle',
	'reportedcontent:refresh' => 'Päivitä lista',
	'reportedcontent:report' => 'Ilmoita ylläpitäjälle',
	'reportedcontent:instructions' => 'Tämä ilmoitus lähetetään sivuston ylläpitäjälle tarkistettavaksi.',
	'reportedcontent:numbertodisplay' => 'Näytettävien kohteiden määrä',
	'reportedcontent:user' => 'Ilmianna käyttäjä',

	'reportedcontent:failed' => 'Ilmoituksen tekeminen epäonnistui.',
	'reportedcontent:notarchived' => 'Ilmoituksen arkistoiminen epäonnistui',
	
	'widgets:reportedcontent:name' => 'Reported content',
	'widgets:reportedcontent:description' => 'Display reported content',
);
